const char * _sound_service = 
"<!DOCTYPE node PUBLIC \"-//freedesktop//DTD D-BUS Object Introspection 1.0//EN\" \"http://www.freedesktop.org/standards/dbus/1.0/introspect.dtd\">\n"
"<node name=\"/com/canonical/indicators/sound\">\n"
"  <interface name=\"com.canonical.indicators.sound\">\n"
"    <method name = \"BlacklistMediaPlayer\">\n"
"        <annotation name=\"org.freedesktop.DBus.GLib.Async\" value=\"true\"/>\n"
"        <arg type='s' name='player_desktop_name' direction=\"in\"/>\n"
"        <arg type='b' name='blacklist' direction=\"in\"/>\n"
"        <arg type='b' name='result' direction=\"out\"/>\n"
"    </method>\n"
"    <method name = \"IsBlacklisted\">\n"
"        <annotation name=\"org.freedesktop.DBus.GLib.Async\" value=\"true\"/>\n"
"        <arg type='s' name='player_desktop_name' direction=\"in\"/>\n"
"        <arg type='b' name='result' direction=\"out\"/>\n"
"    </method>\n"
"    <method name = \"GetSoundState\">\n"
"        <annotation name=\"org.freedesktop.DBus.GLib.Async\" value=\"true\"/>\n"
"        <arg type='i' name='current_state' direction=\"out\"/>\n"
"    </method>\n"
"    <method name = \"EnableTrackSpecificItems\">\n"
"        <annotation name=\"org.freedesktop.DBus.GLib.Async\" value=\"true\"/>\n"
"        <arg type='o' name='player_object_path' direction=\"in\"/>\n"
"        <arg type='s' name='player_desktop_id' direction=\"in\"/>\n"
"    </method>\n"
"    <method name = \"EnablePlayerSpecificItems\">\n"
"        <annotation name=\"org.freedesktop.DBus.GLib.Async\" value=\"true\"/>\n"
"        <arg type='o' name='player_object_path' direction=\"in\"/>\n"
"        <arg type='s' name='player_desktop_id' direction=\"in\"/>\n"
"    </method>    \n"
"    <signal name=\"SoundStateUpdate\">\n"
"      <arg name=\"new_state\" type=\"i\" direction=\"out\"/>\n"
"    </signal>\n"
"  </interface>\n"
"</node>\n"
"\n"
;
